==> tine20-allinone_2020.03.4.tar.bz2: Tasks/js/Tasks-lang-ca-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: ca\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "GENDER_Task, GENDER_Tasks"
: [
  ""
 ,""

]
, "Task, Tasks"
: [
  "Tasca"
 ,"Tasques"

]
, "Percent"
: "Percentatge"

, "Completed"
: "Completada"

, "Due"
: "Venciment"

, "Class"
: ""

, "Description"
: "Descripció"

, "Geo"
: ""

, "Location"
: ""

, "Organizer"
: "Organitzador"

, "Priority"
: "Prioritat"

, "Status, Status"
: [
  ""
 ,""

]
, "Lead"
: "Client potencial"

, "Telephone"
: "Telèfon"

, "Email"
: "Correu electrònic"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Heu de proporcionar una data de venciment, perquè s'estableix una alarma!"

, "Summary"
: "Resum"

, "Due date"
: "Data de venciment"

, "Add Responsible ..."
: "Afegeix un responsable ..."

, "Notes"
: "Notes"

, "Enter description..."
: "Introduïu una descripció"

, "Percentage"
: "Percentatge"

, "Tasks"
: "Tasques"

, "to do list, to do lists"
: [
  "llista de coses a fer"
 ,"llistes de coses a fer"

]
, "to do lists"
: "llistes de coses a fer"

, "Quick Search"
: ""

, "Due Date"
: "Data de venciment"

, "Responsible"
: "Responsable"

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Data de creació"

, "Created By"
: ""

, "New Task"
: ""

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Esteu segur que voleu eliminar la tasca seleccionada?"
 ,"Esteu segur que voleu eliminar les tasques seleccionades?"

]
, "Attachments"
: ""

, "Tags"
: "Etiquetes"

, "Lead name"
: ""

, "Add a task..."
: "Afegeix una tasca..."

, "All my tasks"
: "Totes les meves tasques"

, "Default Favorite"
: "Preferit per defecte"

, "The default favorite which is loaded on Tasks startup"
: "El preferit per defecte que es carrega a l'inici de Tasques"

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "manage shared task lists"
: "gestiona les llistes de tasques compartides"

, "Create new shared tasks lists"
: "Crea noves llistes de tasques compartides"

, "manage shared tasks favorites"
: "gestiona els preferits de les tasques compartides"

, "Create or update shared tasks favorites"
: "Crea o actualitza preferits de tasques compartides"

, "%s's personal tasks"
: "tasques personals de %s"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Totes les tasques de les meves llistes de tasques"

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: ""

, "All tasks that I have last modified"
: ""

, "Tasks without responsible"
: ""

, "GENDER_Task"
: ""

, "Task"
: "Tasca"

, "Status"
: ""

, "to do list"
: "llista de coses a fer"

, "Do you really want to delete the selected task?"
: "Esteu segur que voleu eliminar la tasca seleccionada?"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Tasks/js/Tasks-lang-ca-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Tasks **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Tasks'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Add New Task"
: ""

, "You have to supply a due date, because an alarm ist set!"
: "Heu de proporcionar una data de venciment, perquè s'estableix una alarma!"

, "Summary"
: "Resum"

, "Due date"
: "Data de venciment"

, "Priority"
: "Prioritat"

, "Organizer"
: "Organitzador"

, "Add Responsible ..."
: "Afegeix un responsable ..."

, "Notes"
: "Notes"

, "Enter description..."
: "Introduïu una descripció"

, "Percentage"
: "Percentatge"

, "Status, Status"
: [
  ""
 ,""

]
, "Completed"
: "Completada"

, "Do you really want to delete the selected task?, Do you really want to delete the selected tasks?"
: [
  "Esteu segur que voleu eliminar la tasca seleccionada?"
 ,"Esteu segur que voleu eliminar les tasques seleccionades?"

]
, "Attachments"
: ""

, "Tags"
: "Etiquetes"

, "Lead name"
: ""

, "Add a task..."
: "Afegeix una tasca..."

, "Due Date"
: "Data de venciment"

, "Percent"
: "Percentatge"

, "Responsible"
: "Responsable"

, "Task, Tasks"
: [
  "Tasca"
 ,"Tasques"

]
, "Tasks"
: "Tasques"

, "to do list, to do lists"
: [
  "llista de coses a fer"
 ,"llistes de coses a fer"

]
, "to do lists"
: "llistes de coses a fer"

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Data de creació"

, "Created By"
: ""

, "New Task"
: ""

, "All my tasks"
: "Totes les meves tasques"

, "Default Favorite"
: "Preferit per defecte"

, "The default favorite which is loaded on Tasks startup"
: "El preferit per defecte que es carrega a l'inici de Tasques"

, "Default Task List"
: ""

, "The default task list to create new tasks in."
: ""

, "Enable Standard Alarm"
: ""

, "New task get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the task ends"
: ""

, "Tasks status available"
: ""

, "Possible tasks status. Please note that additional attendee status might impact other Tasks systems on export or syncronisation."
: ""

, "No response"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Task priorities available"
: ""

, "Possible task priorities. Please note that additional priorities might impact other Tasks systems on export or syncronisation."
: ""

, "low"
: ""

, "normal"
: ""

, "high"
: ""

, "urgent"
: ""

, "%s's personal tasks"
: "tasques personals de %s"

, "GENDER_Task"
: ""

, "Due"
: "Venciment"

, "Class"
: ""

, "Description"
: "Descripció"

, "Geo"
: ""

, "Location"
: ""

, "Lead"
: "Client potencial"

, "Telephone"
: "Telèfon"

, "Email"
: "Correu electrònic"

, "Notification for Task %1$s"
: ""

, "All tasks of my taskslists"
: "Totes les tasques de les meves llistes de tasques"

, "My open tasks"
: ""

, "My open tasks this week"
: ""

, "All tasks for me"
: ""

, "All tasks that I am responsible for"
: ""

, "Last modified by me"
: ""

, "All tasks that I have last modified"
: ""

, "Tasks without responsible"
: ""

, "manage shared task lists"
: "gestiona les llistes de tasques compartides"

, "Create new shared tasks lists"
: "Crea noves llistes de tasques compartides"

, "manage shared tasks favorites"
: "gestiona els preferits de les tasques compartides"

, "Create or update shared tasks favorites"
: "Crea o actualitza preferits de tasques compartides"

, "Status"
: ""

, "Do you really want to delete the selected task?"
: "Esteu segur que voleu eliminar la tasca seleccionada?"

, "Task"
: "Tasca"

, "to do list"
: "llista de coses a fer"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
